@@ -14,7 +14,7 @@ Data::Chronicle::Reader - Provides reading from an efficient data storage for vo
 
 =cut
 
-our $VERSION = '0.17';    ## VERSION
+our $VERSION = '0.18';    ## VERSION
 
 =head1 DESCRIPTION
 
@@ -37,32 +37,12 @@ In addition to caching every incoming data, it is also stored in PostgreSQL for
 
 =item B<Transparent>
 
-This modules hides all the details about distribution, caching, database structure and ... from developer. He only needs to call a method
+This modules hides all the internal details including distribution, caching, and database structure from the developer. He only needs to call a method
 to save data and another method to retrieve it. All the underlying complexities are handled by the module.
 
 =back
 
-There are three important methods this module provides:
-
-=over 4
-
-=item C<set>
-
-Given a category, name and value stores the JSONified value in Redis and PostgreSQL database under "category::name" group and also stores current
-system time as the timestamp for the data (Which can be used for future retrieval if we want to get data as of a specific time). Note that the value
-MUST be either hash-ref or array-ref.
-
-=item C<get>
-
-Given a category and name returns the latest version of the data according to current Redis cache
-
-=item C<get_for>
-
-Given a category, name and timestamp returns version of data under "category::name" as of the given date (using a DB lookup).
-
-=back
-
-=head1 Example
+=head1 EXAMPLE
 
  my $d = get_some_log_data();
 
@@ -74,9 +54,6 @@ Given a category, name and timestamp returns version of data under "category::na
     cache_reader => $reader,
     dbic         => $dbic);
 
- my $chronicle_r2 = Data::Chronicle::Reader->new(
-    cache_reader => $hash_ref);
-
  #store data into Chronicle - each time we call `set` it will also store
  #a copy of the data for historical data retrieval
  $chronicle_w->set("log_files", "syslog", $d);
@@ -89,10 +66,11 @@ Given a category, name and timestamp returns version of data under "category::na
 
 =cut
 
+=head1 METHODS
+
 =head2 cache_reader
 
-cache_reader can be an object which has `get` method used to fetch data.
-or it can be a plain hash-ref.
+cache_reader should be an instance of L<RedisDB>.
 
 =cut
 
@@ -103,7 +81,7 @@ has 'cache_reader' => (
 
 =head2 dbic
 
-dbic should be an object of DBIx::Connector.
+dbic should be an instance of L<DBIx::Connector>.
 
 =cut
 
@@ -113,7 +91,11 @@ has 'dbic' => (
     default => undef,
 );
 
-=head3 C<< my $data = get("category1", "name1") >>
+=head2 get
+
+Example:
+
+    my $data = get("category1", "name1");
 
 Query for the latest data under "category1::name1" from the cache reader.
 Will return `undef` if the data does not exist.
@@ -131,7 +113,11 @@ sub get {
     return undef;
 }
 
-=head3 C<< my $data = mget([["category1", "name1"], ["category2", "name2"], ...]) >>
+=head2 mget
+
+Example:
+
+    my @values = mget([["category1", "name1"], ["category2", "name2"], ...]);
 
 Query for the latest data under "category1::name1", "category2::name2", etc from the cache reader.
 Will return an arrayref containing results in the same ordering, with `undef` if the data does not exist.
@@ -144,17 +130,15 @@ sub mget {
 
     my @keys = map { $_->[0] . '::' . $_->[1] } @$pairs;
 
-    if (blessed($self->cache_reader)) {
-        my @cached_data = $self->cache_reader->mget(@keys);
-        return map { decode_json_utf8($_) if $_ } @cached_data;
-    } else {
-        return map { $self->cache_reader->{$_} } @keys;
-    }
-
-    return undef;
+    my @cached_data = $self->cache_reader->mget(@keys);
+    return map { decode_json_utf8($_) if $_ } @cached_data;
 }
 
-=head3 C<< my $data = get_for("category1", "name1", 1447401505) >>
+=head2 get_for
+
+Example:
+
+    my $data = get_for("category1", "name1", 1447401505);
 
 Query Pg archive for the data under "category1::name1" at or exactly before the given epoch/Date::Utility.
 
@@ -184,7 +168,11 @@ sub get_for {
     return decode_json_utf8($db_value);
 }
 
-=head3 C<< my $data = get_for_period("category1", "name1", 1447401505, 1447401900) >>
+=head2 get_for_period
+
+Example:
+
+    my $data = get_for_period("category1", "name1", 1447401505, 1447401900)
 
 Query Pg historical data and return records whose date is between given period.
 
@@ -221,7 +209,11 @@ sub get_for_period {
     return \@result;
 }
 
-=head3 C<< my $data = get_history("category1", "name1", 1) >>
+=head2 get_history
+
+Example:
+
+    my $data = get_history("category1", "name1", 1);
 
 Query Pg archive for the data under "category1::name1" at the provided number of revisions in the past.
 
@@ -290,7 +282,7 @@ L<http://cpanratings.perl.org/d/Data-Chronicle>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/Data-Chronicle/>
+L<https://metacpan.org/release/Data-Chronicle/>
 
 =back
 
